"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = transformButton;
const transforms_1 = require("../../shared/transforms");
/**
 * Transforms Button:
 * - Change variant="cta" to variant="accent"
 * - Change variant="overBackground" to variant="primary" staticColor="white"
 * - Change style to fillStyle
 * - Comment out isPending (it has not been implemented yet)
 * - Remove isQuiet (it is no longer supported in Spectrum 2)
 * - If href is present, the Button should be converted to a LinkButton
 * - Remove elementType (it is no longer supported in Spectrum 2).
 */
function transformButton(path) {
    // Change variant="cta" to variant="accent"
    (0, transforms_1.updatePropNameAndValue)(path, {
        oldPropName: 'variant',
        oldPropValue: 'cta',
        newPropName: 'variant',
        newPropValue: 'accent'
    });
    // Change variant="overBackground" to variant="primary" staticColor="white"
    (0, transforms_1.updatePropValueAndAddNewPropName)(path, {
        oldPropName: 'variant',
        oldPropValue: 'overBackground',
        newPropName: 'variant',
        newPropValue: 'primary',
        additionalPropName: 'staticColor',
        additionalPropValue: 'white'
    });
    // Change style to fillStyle
    (0, transforms_1.updatePropName)(path, {
        oldPropName: 'style',
        newPropName: 'fillStyle'
    });
    // Comment out isPending
    (0, transforms_1.commentOutProp)(path, { propName: 'isPending' });
    // Remove isQuiet
    (0, transforms_1.removeProp)(path, { propName: 'isQuiet' });
    // If href is present, the Button should be converted to a LinkButton
    (0, transforms_1.updateComponentIfPropPresent)(path, {
        propName: 'href',
        newComponentName: 'LinkButton'
    });
    // Remove elementType
    (0, transforms_1.removeProp)(path, { propName: 'elementType' });
}
